@@ -56,7 +56,11 @@ POSSIBILITY OF SUCH DAMAGE.
 //
 namespace libtorrent {
 
-	namespace aux { struct session_impl; struct session_settings; }
+namespace aux {
+	struct session_impl;
+	struct session_settings;
+	struct session_settings_single_thread;
+}
 
 	struct settings_pack;
 	struct bdecode_node;
@@ -65,8 +69,13 @@ namespace libtorrent {
 	TORRENT_EXTRA_EXPORT void save_settings_to_dict(aux::session_settings const& s, entry::dictionary_type& sett);
 	TORRENT_EXTRA_EXPORT void apply_pack(settings_pack const* pack, aux::session_settings& sett
 		, aux::session_impl* ses = nullptr);
+	TORRENT_EXTRA_EXPORT void apply_pack_impl(settings_pack const* pack
+		, aux::session_settings_single_thread& sett
+		, std::vector<void(aux::session_impl::*)()>* callbacks = nullptr);
 	TORRENT_EXTRA_EXPORT void run_all_updates(aux::session_impl& ses);
 
+	// converts a setting integer (from the enums string_types, int_types or
+	// bool_types) to a string, and vice versa.
 	TORRENT_EXPORT int setting_by_name(string_view name);
 	TORRENT_EXPORT char const* name_for_setting(int s);
 
@@ -84,28 +93,42 @@ namespace libtorrent {
 	//
 	struct TORRENT_EXPORT settings_pack
 	{
-		friend TORRENT_EXTRA_EXPORT void apply_pack(settings_pack const* pack, aux::session_settings& sett, aux::session_impl* ses);
+		friend TORRENT_EXTRA_EXPORT void apply_pack_impl(settings_pack const*
+			, aux::session_settings_single_thread&
+			, std::vector<void(aux::session_impl::*)()>*);
 
+		// hidden
 		settings_pack() = default;
 		settings_pack(settings_pack const&) = default;
 		settings_pack(settings_pack&&) noexcept = default;
 		settings_pack& operator=(settings_pack const&) = default;
 		settings_pack& operator=(settings_pack&&) noexcept = default;
 
+		// set a configuration option in the settings_pack. ``name`` is one of
+		// the enum values from string_types, int_types or bool_types. They must
+		// match the respective type of the set_* function.
 		void set_str(int name, std::string val);
 		void set_int(int name, int val);
 		void set_bool(int name, bool val);
-		bool has_val(int name) const;
 		template <typename Type, typename Tag>
 		void set_int(int name, flags::bitfield_flag<Type, Tag> const val)
 		{ set_int(name, static_cast<int>(static_cast<Type>(val))); }
 
+		// queries whether the specified configuration option has a value set in
+		// this pack. ``name`` can be any enumeration value from string_types,
+		// int_types or bool_types.
+		bool has_val(int name) const;
+
 		// clear the settings pack from all settings
 		void clear();
 
 		// clear a specific setting from the pack
 		void clear(int name);
 
+		// queries the current configuration option from the settings_pack.
+		// ``name`` is one of the enumeration values from string_types, int_types
+		// or bool_types. The enum value must match the type of the get_*
+		// function.
 		std::string const& get_str(int name) const;
 		int get_int(int name) const;
 		bool get_bool(int name) const;
@@ -121,6 +144,8 @@ namespace libtorrent {
 			index_mask =       0x3fff
 		};
 
+		// enumeration values naming string settings in the pack. To be used with
+		// get_str() and set_str().
 		enum string_types
 		{
 			// this is the client identification to the tracker. The recommended
@@ -241,6 +266,8 @@ namespace libtorrent {
 			max_string_setting_internal
 		};
 
+		// enumeration values naming boolean settings in the pack. To be used with
+		// get_bool() and set_bool().
 		enum bool_types
 		{
 			// determines if connections from the same IP address as existing
@@ -729,9 +756,22 @@ namespace libtorrent {
 			// changes are taken in consideration.
 			enable_ip_notifier,
 
+			// when this is true, nodes whose IDs are derived from their source IP
+			// according to BEP 42 (http://bittorrent.org/beps/bep_0042.html) are
+			// preferred in the routing table.
+			dht_prefer_verified_node_ids,
+
+			// when this is true, create an affinity for downloading 4 MiB extents
+			// of adjecent pieces. This is an attempt to achieve better disk I/O
+			// throughput by downloading larger extents of bytes, for torrents with
+			// small piece sizes
+			piece_extent_affinity,
+
 			max_bool_setting_internal
 		};
 
+		// enumeration values naming integer settings in the pack. To be used with
+		// get_int() and set_int().
 		enum int_types
 		{
 			// ``tracker_completion_timeout`` is the number of seconds the tracker
@@ -1162,7 +1202,6 @@ namespace libtorrent {
 			// favour of a choked peer.
 			seeding_piece_quota,
 
-			// TODO: deprecate this
 			// ``max_rejects`` is the number of piece requests we will reject in a
 			// row while a peer is choked before the peer is considered abusive
 			// and is disconnected.
